function [ results ] = MIbin(data1,data2,cfg)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculation of mutual information between two signal using a binning
%estimator.
%   data1: input data, 1xN, double
%   data1: input data, 1xM, double
%%CONFIGURATION STRUCTURE:
%   cfg.numbin: number of bins,  1x1, int, default: 0 (optimization using Freedman-Diaconis rule)
%OUTPUT:
%   results.cfg: configuration structure
%   results.MI: Mutual information [bit], 1x1, double
%   results.lMI: Local mutual information [bit], 1xN, double
%   results.jp: Joint probabilities, numbin x numbin
%   results.m1: marginal probability 1, 1xnumbin
%   results.m2:  marginal probability 2,1xnumbin
%DEPENDENCIES:
%   freeddiac
%Author: Immo Weber, 2018
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%read in parameters%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if isfield(cfg,'numbin')==1
numbin=cfg.numbin;
else
    numbin=0;
    disp('No number of bins specified! Assigning default: 0 (optimization)')
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
data1=(data1-mean(data1))./std(data1);
data2=(data2-mean(data2))./std(data2);

if numbin==0
    numbin1=freeddiac(data1);
    numbin2=freeddiac(data2);
    numbin=min([numbin1 numbin2]);
end

combdata(:,1)=data1;
combdata(:,2)=data2;
[N,Xedges,Yedges,binX,binY] = histcounts2(data1,data2,[numbin numbin]);

bindata1=Xedges(2)-Xedges(1);
bindata2=Yedges(2)-Yedges(1);

%%%estimation of p(x,y)%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
jp=N;
areajp=bindata1*bindata2*nansum(nansum(N));
jp=jp/areajp;
%%%estimation of p(x)%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
mdata1=nansum(N);
areadata1=bindata1*nansum(nansum(N));
mdata1=mdata1/areadata1;
%%%estimation of p(y)%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
mdata2=nansum(N');
areadata2=bindata2*nansum(nansum(N));
mdata2=mdata2/areadata2;
%%%estimation of MI%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
SI1=-log2(mdata1);
SI2=-log2(mdata2);
Hdata1=nansum((mdata1*bindata1).*SI1);
Hdata2=nansum((mdata2*bindata2).*SI2);

temp=-log2(jp);
temp(isinf(temp)==1)=0;
SI12=temp;
Hdata1data2=sum(nansum((jp*bindata1*bindata2).*SI12));

MI=Hdata1+Hdata2-Hdata1data2;
lMItemp=SI1+SI2-SI12;


for i=1:length(data1)
    lMI(i)=lMItemp(binX(i),binY(i));
end
 

%%%generate output structure%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
results.cfg=cfg;
results.MI=MI;
results.lMI=lMI;
results.jp=jp;
results.m1=mdata1;
results.m2=mdata2;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end