function results=entropybin(data,cfg)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculates the Shannon entropy using a binning estimator.
%   data: input data, 1xN, double
%CONFIGURATION STRUCTURE:
%   cfg.numbin: number of bins,  1x1, int, default: 0 (optimization using Freedman-Diaconis rule)
%OUTPUT:
%   results.Hx: Shannon entropy [bit], 1x1, double
%   results.SI: Shannon information [bit], 1xN, double
%   results.dist: Probability distribution. 
%DEPENDENCIES:
%   freeddiac
%Author: Immo Weber, 2018
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%read in parameters%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if isfield(cfg,'numbin')==1
numbin=cfg.numbin;
else
    numbin=0;
    disp('No number of bins specified! Assigning default: 0 (optimization)')
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
data=zscore(data);

if numbin==0
    numbin=freeddiac(data);
end
[N,edges,bin] = histcounts(data,numbin);
bindata=edges(2)-edges(1);


mdata=N;
areadata=bindata*(nansum(N));
mdata=mdata/areadata;

SI=-log2(mdata);
Hx=nansum((mdata.*bindata).*SI);


SI=SI(bin);
     

%%%generate output structure%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
results.cfg=cfg;
results.Hx=Hx;
results.SI=SI;
results.dist=mdata;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end